@@ -12,6 +12,9 @@ def get_distro_info(root_dir):
 
     obj = distro.LinuxDistribution(include_lsb=False, include_uname=False)
 
+    # Fixes a bug in distro: https://github.com/python-distro/distro/issues/309
+    obj._uname_info = {}
+
     # NOTE: The parsing of LinuxDistribution distro information is done in a lazy way.
     # This will force the parsing to happen before we restore the old value of _UNIXCONFDIR.
     _ = obj.info()
